@@ -2,20 +2,11 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Mail",
-    "Sent" : "Trimis",
-    "Drafts" : "Schițe",
-    "Archive" : "Arhivă",
-    "Trash" : "Gunoi",
-    "All" : "Toate ",
-    "Favorites" : "Favorite",
     "Creating account failed: " : "Crearea contului a eșuat:",
-    "Delete permanently" : "Șterge permanent",
     "Name" : "Nume",
     "Password" : "Parolă",
     "Manual" : "Manual",
     "Connect" : "Conectare",
-    "from" : "de la",
-    "to" : "către",
     "Subject" : "Subiect",
     "Sending …" : "Se trimite...",
     "Message sent!" : "Mesaj trimis!",
