@@ -3,27 +3,27 @@ OC.L10N.register(
     {
     "Mail" : "邮件",
     "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
-    "Updating account failed: " : "更新账户失败：",
-    "Creating account failed: " : "未能创建账户：",
-    "💌 A mail app for Nextcloud" : "💌 Nextcloud上的一款邮件应用",
-    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud上的一款邮件应用**\n\n- **🚀 与其他Nextcloud应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何IMAP账号。\n- **🔒 收发加密邮件！** 使用很棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复发明轮子！** 基于很棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
+    "Updating account failed: " : "更新账号失败：",
+    "Creating account failed: " : "未能创建账号：",
+    "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
+    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
     "Auto" : "自动",
     "Name" : "姓名",
     "Mail Address" : "邮箱",
     "Password" : "密码",
-    "Manual" : "手册",
-    "IMAP Settings" : "IMAP设置",
+    "Manual" : "手动",
+    "IMAP Settings" : "IMAP 设置",
     "IMAP Host" : "IMAP 主机",
-    "IMAP Security" : "IMAP安全",
+    "IMAP Security" : "IMAP 安全",
     "None" : "无",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP 端口",
     "IMAP User" : "IMAP 用户",
     "IMAP Password" : "IMAP 密码",
-    "SMTP Settings" : "SMTP设置",
+    "SMTP Settings" : "SMTP 设置",
     "SMTP Host" : "SMTP 主机",
-    "SMTP Security" : "SMTP安全",
+    "SMTP Security" : "SMTP 安全",
     "SMTP Port" : "SMTP 端口",
     "SMTP User" : "SMTP 用户",
     "SMTP Password" : "SMTP 密码",
@@ -32,12 +32,24 @@ OC.L10N.register(
     "Add mail account" : "添加邮件账户",
     "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
     "Keyboard shortcuts" : "键盘快捷方式",
-    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装Mailvelope浏览器扩展！",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
+    "From" : "发件人",
+    "Select account" : "选择账号",
+    "To" : "收件人",
+    "Contact or email address …" : "联系人或邮箱地址...",
+    "+ Copy" : "+ 抄送",
+    "Copy" : "副本",
+    "No contacts found." : "未找到联系人。",
+    "Blind copy" : "无信头副本",
     "Subject" : "主题",
+    "Subject …" : "标题...",
+    "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
+    "Write message …" : "编写消息...",
     "Saving draft …" : "保存草稿 …",
     "Draft saved" : "草稿已保存",
-    "Message options" : "消息选项",
-    "Plain text" : "纯文本",
+    "Upload attachment" : "上传附件",
+    "Add attachment from Files" : "从文件添加附件",
+    "Enable formatting" : "启用格式化",
     "Uploading attachments …" : "上传附件 …",
     "Sending …" : "正在发送…",
     "Error sending your message" : "发送您的消息时出错",
@@ -45,22 +57,22 @@ OC.L10N.register(
     "Retry" : "重试",
     "Message sent!" : "消息已发送！",
     "Reply sent!" : "回复已发送！",
-    "Write another message" : "写另一条消息",
+    "Write another message" : "再写一条消息",
     "Send" : "发送",
     "Uploading {percent}% …" : "正在上传 {percent}% …",
-    "Upload attachment" : "上传附件",
-    "Add attachment from Files" : "从文件添加附件",
     "Choose a file to add as attachment" : "选择文件添加为附件",
     "Writing mode" : "编写模式",
-    "Preferred writing mode for new messages and replies." : "新邮件及回复邮件的偏好编写模式。",
+    "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
+    "Plain text" : "纯文本",
     "Rich text" : "富文本",
     "No messages in this folder" : "该文件夹内没有消息",
     "Draft: " : "草稿: ",
     "Mark read" : "标记为已读",
     "Mark unread" : "标记为未读",
     "Delete" : "删除",
+    "Blind copy recipients only" : "仅向收件人发送无信头副本",
     "Report this bug" : "报告此问题",
-    "Loading messages" : "加载消息",
+    "Loading messages" : "正在加载消息",
     "Not found" : "没有找到",
     "Reply" : "回复",
     "Reply to sender only" : "只回复发送者",
@@ -82,13 +94,17 @@ OC.L10N.register(
     "Show all folders" : "显示全部文件夹",
     "Collapse folders" : "折叠文件夹",
     "Mark all as read" : "标记所有为已读",
+    "Mark all messages of this folder as read" : "将此文件夹中的所有消息都标记为已读",
     "Add subfolder" : "添加子文件夹",
-    "{total} messages" : "{total}封邮件",
-    "{unread} unread of {total}" : "总共{total}封邮件，{unread}封未读邮件",
+    "{total} messages" : "{total} 封邮件",
+    "{unread} unread of {total}" : "总共 {total} 封邮件，{unread} 封未读邮件",
+    "Loading …" : "加载中...",
     "Could not load your draft" : "无法加载您的草稿",
+    "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
     "Signature" : "签名",
-    "A signature is added to the text of new messages and replies." : "签名已加入到新邮件及回复邮件的文本中。",
+    "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
+    "Signature …" : "签名...",
     "Save signature" : "保存签名",
     "Account settings" : "账号设置",
     "Change name" : "更改名称",
@@ -101,16 +117,16 @@ OC.L10N.register(
     "Toggle unread" : "切换未读",
     "Search" : "搜索",
     "Refresh" : "刷新",
-    "Connect your mail account" : "连接您的邮件账户",
+    "Connect your mail account" : "连接您的邮件账号",
+    "Unexpected error during account creation" : "创建账号时发生意外错误",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
     "Nextcloud Mail" : "Nextcloud 邮件",
-    "All inboxes" : "所有收件箱",
     "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
     "Could not load the desired message" : "无法加载想要的消息",
     "Could not load the message" : "无法加载该消息",
-    "Error loading message" : "载入电邮时发生错误",
+    "Error loading message" : "载入消息时发生错误",
     "Forwarding to %s" : "转发给 %s",
     "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
     "Redirect" : "重定向",
